Life table calculations to be used in make_life_table(). This function isn't exported in the package.
Source: R/life-expectancy.R
life_table.Rdthis is the function called in the make_life_table(). It calculates the vectors required for creating life expectancy methods outlined in the Public Health England calculator that lives here.